@@ -21,6 +21,7 @@ except:
 # 'auth_host': Authentication server to use
 # 'cache_dir': Cache directory to use
 # 'verbose': Verbose mode if set to True
+# 'force': Force action (overwrite existing files)
 
 def connect(options):
     return KeystokClient(options)
@@ -57,6 +58,8 @@ class KeystokClient:
             self.options['cache_dir'] = os.path.join(self.options['dir'], 'cache')
         if not self.options.get('verbose', None):
             self.options['verbose'] = False
+        if not self.options.get('force', None):
+            self.options['force'] = False
         # Ensure cache directory exists
         safe_mkdir(self.options['cache_dir'], 0o700)
         # Create full cache path with application ID in it
@@ -108,7 +111,7 @@ class KeystokClient:
             # Key(s) not configured, give up
             sys.stderr.write('keystok: sshautoconfig: ssh key(s) not configured in application, aborting.\n')
             return 1
-        if os.path.isfile(ssh_public_key_path) or os.path.isfile(ssh_private_key_path):
+        if not self.options['force'] and (os.path.isfile(ssh_public_key_path) or os.path.isfile(ssh_private_key_path)):
             # Key(s) already saved, give up
             sys.stderr.write('keystok: sshautoconfig: ssh key(s) already exist, aborting.\n')
             return 1
@@ -203,6 +206,7 @@ def main():
     parser.add_argument('-d', '--dir', type=str, help='Specify Keystok directory (overrides $KEYSTOK_DIR, defaults to ~/.keystok)')
     parser.add_argument('-c', '--cache-dir', type=str, help='Specify cache directory (overrides $KEYSTOK_CACHE_DIR, defaults to ~/.keystok/cache)')
     parser.add_argument('-v', '--verbose', action='store_true', help='Show verbose output')
+    parser.add_argument('-f', '--force', action='store_true', help='Force action (overwrite existing files)')
     parser.add_argument('command', choices=['ls', 'get', 'sshautoconfig'], help='Command to execute')
     parser.add_argument('args', nargs=argparse.REMAINDER)
     args = parser.parse_args()
@@ -245,6 +249,7 @@ def main():
         'dir': keystok_dir,
         'cache_dir': cache_dir,
         'verbose': args.verbose,
+        'force': args.force,
     })
     cmd = getattr(client, 'cmd_' + args.command)
     if not cmd:
